Struct Message
Source pub struct Message {
pub message_type: MessageType,
pub payload: Bytes,
}
Create a new text message.
Create a new binary message.
Create a new ping message.
Create a new pong message.
Create a JSON message from a serializable value.
Parse the message payload as JSON.
Get the message payload as a string.
Get the message payload as bytes.
Check if this is a text message.
Check if this is a binary message.
Check if this is a ping message.
Check if this is a pong message.
Check if this is a close message.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.