RoomManager

Struct RoomManager 

pub struct RoomManager { /* private fields */ }
Manages rooms and their members.

Implementations

Source

impl RoomManager

pub fn new() -> Self

Create a new room manager.

pub fn register_connection(&self, connection: Connection)

Register a connection.

pub fn unregister_connection(&self, connection_id: &str)

Unregister a connection and remove it from all rooms.

pub fn get_connection(&self, connection_id: &str) -> Option<Connection>

Get a connection by ID.

pub fn create_room(&self, room_id: RoomId) -> Arc<Room>

Create a room if it doesn’t exist.

pub fn get_room(&self, room_id: &str) -> Option<Arc<Room>>

Get a room by ID.

pub fn delete_room(&self, room_id: &str) -> bool

Delete a room.

pub fn join_room( &self, connection_id: &str, room_id: &str, ) -> WebSocketResult<()>

Join a connection to a room.

pub fn leave_room( &self, connection_id: &str, room_id: &str, ) -> WebSocketResult<()>

Remove a connection from a room.

pub fn broadcast_to_room( &self, room_id: &str, message: Message, ) -> WebSocketResult<usize>

Broadcast a message to all connections in a room.

pub fn broadcast_to_room_except( &self, room_id: &str, message: Message, except_id: &str, ) -> WebSocketResult<usize>

Broadcast a message to all connections in a room except one.

pub fn broadcast_all(&self, message: Message) -> usize

Broadcast a message to all connections.

pub fn room_ids(&self) -> Vec<RoomId>

Get all room IDs.

pub fn connection_ids(&self) -> Vec<ConnectionId>

Get all connection IDs.

pub fn connection_count(&self) -> usize

Get the total number of connections.

pub fn room_count(&self) -> usize

Get the total number of rooms.